![Python package](https://github.com/inductiva/inductiva/actions/workflows/python-package.yml/badge.svg)

# Inductiva

This repository holds a user-friendly client to Inductiva's scientific computing API.
